Changelog
=========

0.3.1 (2013-05-05)
------------------

- Prevent errors on regex lookups with SQLite (`issue #5 <https://github.com/noirbizarre/django-eztables/issues/5>`_)


0.3.0 (2013-04-30)
------------------

- Python 3 support
- Documented integration with Django Pipeline or RequireJS
- Package the unminified version too (used when ``settings.DEBUG=True``)


0.2.2 (2013-03-02)
------------------

- Django 1.5 compatibility
- Added custom search and sort demo


0.2.1 (2013-02-08)
------------------

- Fix formatting with unicode


0.2 (2013-02-07)
----------------

- Handle custom server-side search implementation
- Handle custom server-side sort implementation


0.1.2 (2013-02-07)
------------------

- Fix static files packaging


0.1.1 (2013-02-07)
------------------

- Fix requirements packaging


0.1 (2013-02-07)
----------------

- Initial implementation
